Title: Collaboration Agreement
Authors: Open Source Publishing ASBL


In this text, we invite you to work together in a specific way; to explain the backgrounds of this specific way and sketch out the practical implications.

# Open Source Publishing (OSP)

## Who are we, and where do we come from?
OSP is a heterogenous group of practioners making graphic design using only free and open source software — pieces of software that invite their users to take part in their elaboration. It was founded in 2006 in the context of Brussels art organisation Constant. At that time, we were making posters and books for open content but using proprietary software and it started to feel odd. At the same time, Adobe was buying Macromedia, leading to its quasi-monopoly on the graphic design software market. We became increasingly interested in how tools convey ways of doing that shape our practices. 

## How tools and free software change practice
Part of working in any field is to know the tools available and be able to appropriate and customise them. Even though the final output of graphic design and publishing processes might be printed matter, its creation process nowadays involves primarily digital tools. Software then deserve to be scrutinised. In Graphic Design and Publishing, one software company has a monopoly. This means practitioners that might work in hugely varied circumstances with widely varying aims and interests, all have to contend themselves with the same hammer. Software is necessarily full of conventions, often based on and re-inforcing pre-existing labor organisations. In the mainstream commercial software (Adobe), it is no surprise that one finds inscribed a mainstream working practice. This makes for an impoverished visual culture.

Commercial software tends to hide its digital materiality behind slick interfaces, giving the false impression that software is “just” a vehicle, a transparent means for connecting creative ideas to the final output. The culture of Free and Libre software inverses the situation by putting the inner workings of digital tools, their source code, at the center of its practice. To coordinate the development of Free Software projects, it has seen the development of a series of social and intellectual tools and practices that are inspiring in their breadth.

Our practice has been shaped by the encounter with the tools and the culture of Free Software. 

&nbsp;
{: style="height: 2.6cm;"}

# Definition of the research field

<!-- if this stays in bullet points, it should be a summary of what follows. otherwise it should be rewritten to paragraphs and be more explicit (these points stay abstract)-->
<!-- this is a draft, meant to be developed -->
- we decide together with you the outcome we want to reach. Aiming for a common goal, but not a specific object
- we do so with a timeframe and a budget frame in mind
- practice redefines the outcomes
- valorise the trip, and not only the destination
- replacing “deadline” by “milestone”, and “estimate” by “roadmap” is already a good start 
- we agree on when to stop
- we gradually learn how our ideas about design can drive the instant need to meet deadlines

A commission is not just a job <!-- commission != job != collaboration -->. Our way of working is strongly lead by a process of research,  a trip which is more enriching to us —and we hope to you as well—  than only the final outcome (appropriating new tools, new workflows).

As a field of creation, graphic design is inherently concerned with research, and a studio that wouldn’t claim for it would be surprising. We do also strongly embrace the research aspect, but consider research on a larger scope. True research is about taking risks, exploring new territories, questioning our confidence and accepting to step out our comfort zone.

Too often, requirements and specifications are preliminary to the job. Requirements include media output definition and technologies; or in other words “means”. Sometimes, the scope of those means is limited by our imagination or previous experiences. Some other times, we fantasize about the perfect system that would fit them all without managing to grasp it.

The first case tends to prevent us from engaging in a rich collaboration, where “means” are limitating the scope of imagination, as what we produce and how are so closely intertwingled. The second case tends to lead to vague ideas, unrealistic amount of work and in the end frustration when it comes to something that is only half-baked. 

It is often hard to define a specific goal from the beginning, this is why part of the budget/calendar is dedicated to define altogether what this “something” is, building a shared vocabulary and a common understanding of what the project is and define its scope. Concretely it means that part of the budget and calendar is dedicated to explore new territories without any guarantee of direct outcome at this stage of the project. After this first round of work, OSP and you decide whether to continue together or not. If the project is still on, OSP and you decide, based on the first round of research, on a specific outcome, which could even plan possible post-project developments.

<!-- Learning situation -->

&nbsp;
{: style="height: 6cm;"}

# How do we work together
Free and open source software culture also challenges traditional education paradigms because knowledge is exchanged outside institutional borders, and participants move between roles easily (teacher, student, developer, user). 

<!--  both side involvement (we also expect collaborators to look at what we've done) -->

## The “working team”
Following the motto “never alone”, for each project, a team of two to four persons is set up according to one’s interests and agendas.

## The “conscience”
Represented by one or two people, the conscience is the middle ground between you and the rest of the team. Being the relay does not mean being responsible for the rest of the team. The conscience is often the  person through whom the project came in, or is chosen by affinities with the project, or simply for internal logistics.

## The “external conscience”
We try to set up the status of an external conscience, another member of OSP who is not part of the working team. S·he has the role of forester. <!-- Explain? Make the link with the next sentence? --> This external conscience will have the role of an external eye/advisor, helping with tough decisions, general management, planning or logistics of the research project.

<!-- These  two roles are useful for our ideas of collaborations, but we could  include a sentence saying that these roles could be reversed /  reimagined → what would reversed be? subject to modification → does this really have to be in the collab agreement if still unclear? we can always add it later when it evolves? -->

## Not just a client but a “collaborator”
<!--Steph: I don't understand what we try to say in this part -->
OSP is not imposing any choices, nor you are imposing any choices; we work and decide together. This does not mean everyone is paid the same amount, even between different OSP’s, daily fees can vary according to the different tasks  inside one project. <!-- I imagine you are referring to the fact that we get paid and they pay us? The fact that different OSP’s get paid different amounts is not comparable to that… -->



<!-- What OSP wait from you as a collaborator (that could be phrased in a more welcoming way :))

In case of problems
Examples of problems :
    - deadline not respected from our side
    - deadline not respected from their side
    - deadline impossible to maintain
    - still waiting for payment
    - asking for new things to produce during the work
    - Yes this would be good to have-->


## Tools

> Free Software does not explain why these various changes have occurred, but rather how individuals and groups are responding: by creating new things, new practices, and new forms of life. It is these practices and forms of life —not the software itself— that are most significant, and they have in turn served as templates that others can use and transform: practices of sharing source code, conceptualizing openness, writing copyright (and copyleft) licenses, coordinating collaboration, and proselytizing for all of the above.
> <footer>Chris Kelty, Two Bits: The Cultural Significance of Free Software</footer>

We inherit a set of thoughts and habits from the tools we chose to use. Source sharing and publishing are values we hold strong. 
This is a model that we borrowed from the free software culture, based on how rich, diverse and collaborative it has become.

During a project, the working team works together using a versioning system which houses the files for the one project. This repository is accessible directly on OSP’s website for the collaborator, and also for the outside public. Not only does this enable us to publish sources, but it also keeps track of how the project has progressed over time and who has contributed to it.

<!-- - - - extension / documentation -->



# Intellectual property

> The representational freedom of artists, part of which is the freedom to depict and build or comment on existing culture, to continue the conversation of culture, is the freedom of art. 
> <footer>Rob Myers, Open Source Art Again, 2006</footer>

Free and Open Source License are a “hack” on the traditional copyright system. Because the copyright owner determines who has permission to use the material, the copyright owner can also decide if and how to open it up. To be able to license the designs under a Free and Open Source license, OSP retains the copyright to their designs.

In the joint creation of the design we will be using all kinds of visual and textual materials provided by you or by your partners. In the spirit of OSP, we urge you to use your intellectual property to open up this material under the same copyleft licenses OSP uses, and to convince your partners to do so as well.

The goal of these licenses is that the whole of the project files, both its process and its final result, become available for the community to build upon. This does not mean that strangers will be able to change directly the design we make for you. You and OSP remain responsible for the design we make together. Rather, it enables others to take elements of our work and use it as inspiration for theirs.

We are well aware that it is not always possible to use a license that enables re-use in a modified form. This could be the case, for example, with the logos of supporting organisations. In that case we require at least the right to redistribute these images; in this way the selection of files that makes up a project can still be shared as a whole, even if the usage requirements of the discrete elements differ.

# Sharing Sources

<!-- + sharing accounting (invoices etc.) -->

Free software challenges traditional economical paradigms because professionals and amateurs are part of the same ecosystem, and instead of creating scarcity, embrace the possibility that one’s work can be copied.

The licenses OSP uses on its production are copyleft. It means that anyone is free to reuse, modify and redistribute our materials, even for commercial purposes. That  new flavour of the material has to be, however, redistributed under the same  license: the ecology of sharing is therefore stimulated and preserved. It doesn’t mean we give up our authorship, but that we invite others to get influenced by others and to acknowledge this.

It may sound unusual —even scary— in a society that overvalues the outcome over the process. We don’t mind sharing source as we consider the value of our work to be the creative path that leads to an outcome (*Poiesis*), and not just the outcome itself (*Aesthesis*). In other words, we like to think of our work in terms of practice and not production. Furthermore we think of design as a space for dialogue  and tension between cultures. We see all the parts in the process of  producing design to be parts of culture, from the tools to the recipes  and the final object. And therefore should be free to use by all.

Some edge cases might prevent us from publishing right away the sources  though. In journalism for instance, secrecy is not only an economical  issue but also a requirement: one might need to strategically avoid immediate publishing or even literally protect the sources. The working team and the collaborator agree at the beginning of the project when and what sources are to be published. <!-- in the tools part we specifically say all sources are shared through GIT. -->

# The legal structure of our collaboration
Currently, OSP is a non-profit association. OSP is looking for setting up a cooperative for its commissioned works and keep the non-profit association for its pedagogical and self-initiated activities. The status of a cooperative reflects better than a regular entreprise the fact that OSP wants to keep a research activity in its commissioned works. It also reflects the facts that OSP is not seeking for personal enrichment but that OSP wants to make a framework that is sustainable.

Until we have a cooperative set up, we are working through OSP asbl.  At the start of the project, we set up a quote and decide together with you of the installment payments. This allows us to get paid while working on the project and to prevent to have a huge buffer capital.
A job can’t start without a signed collaboration agreement nor an signed quote which gives insurance for you that we have to deliver a graphical object and for us that our work will be compensated.

# Contact
Open Source Publishing  ASBL  
WTC, tower I, 25th floor  
Boulevard du Roi Albert II 30  
Mailbox 8  
1000 Brussels, Belgium  
VAT number: BE0599.879.870  
miam@osp.kitchen  
http://osp.kitchen



<!--
comments for improvement:
For the who whe are:
        AL: I suggest rewriting/integrating the intro at [[balsa-docu]]

draw a schema ? 

On équipe aussi les collaborateurs avec des outils. Pas de claim sur les propriété intellectuelle

http://git.constantvzw.org/?p=relearn.be.git;a=blob;f=LICENSE.txt;h=998e6632a5fc01b58d9937d1dfcd196bc7941d83;hb=HEAD
out

"One way we deal with this, is by publishing final results side by side with ingredients and recipes. The raw files themselves seem pretty useless once the festival is over and the book printed so we write manuals, stories, histories" FS ?

Aesthesis and Poiesis: http://www.ears.dmu.ac.uk/spip.php?page=rubriqueLang&lang=fr&id_rubrique=1445

Annexes and links
More about OSP
What is in a name
Why OSP thinks fonts should be free software
Awkward Gestures
Interview with Matthew Fuller
Design Tools for Designers
Les Nains, a song by Marie Dubas (1937)

I call it the law of the instrument, and it may be formulated as follows: Give a small boy a hammer, and he will find that everything he encounters needs pounding.
— Abraham Kaplan, The Conduct of Inquiry: Methodology for Behavioral Science, 1964, p28#

Femke’s soup spoon-fork quote? the one or the other

commencer par le how, pour déduire ce que ça change et déduire le why
droit d'auteur, on est payé au temps qu'on passe, et pas plus

créer un paysage
comptabilité en clair et publiée

3. Vie (suite des projets)
a. License
b. relation to collaborators

* * *

We are interested in graphic design as a space of [tension/dialog between public, culture, etc.]  we try to adopt an ecological approach. To do so, by re-inventing the conditions of our practices: task-separation, workflows, education and power struggles. h


-->
<!--
Hey,
      the other day I forwarded a PDF of free art license furniture.
      Christophe André, founder of Entropie sent me an essay published       in this book made in Scribus.
      Quite interesting for OSP's collab agreement and future structure.       They describe at the end of the essay how they earn money.
      
      Below, some interesting quotes for us.
      
      At the bottom is his answer to further questions about how to       structure ourselves + getting paid.
      S.


​      
    """
    L'importance de la documentation
      Une bonne documentation est importante, car c’est elle qui détermine la prise d'autonomie des
      futurs utilisateurs. Si l'on se contente de faire une recette de cuisine sans dévoiler tout le processus
      de conception, de fabrication et d'optimisation, l’utilisateur pourra difficilement prendre en main l'objet.
      La documentation devra donc être composée de la phase de conception qui comprend les choix
      adoptés pour concevoir l'objet, et l’argumentation permettant de comprendre pourquoi certaines
      pistes ont été écartées. Cette phase doit contenir les plans détaillés de l'objet. Il est très important
      de détailler cette phase car elle va permettre au lecteur de s’approprier ces recherches et de les
      adapter éventuellement à un environnement différent.
      Ensuite, il faut détailler la phase de réalisation comprenant les choix techniques ainsi que les
      différents matériaux utilisés. La réalisation est documentée grâce à une série de photos prises
      lors de la construction.
      Vient enfin une phase d'optimisation dans laquelle on met en avant autant les avantages que les
      inconvénients de l'objet. En effet, contrairement au modèle marchand où l'on va cacher les erreurs,
      les ratages, on va ici dévoiler ces problèmes car ils deviennent des ressources pour d'éventuelles
      améliorations. En dévoilant ces problèmes, en les diffusant, on pourra alors avoir des retours
    suggérant des pistes de résolution.
    
    * * *
    La limite du libre c’est la complexité des objets qu’on met en libre : au plus l’objet est complexe, au plus on sera dépendant
    des personnes qui l’ont conçu, même si celles-ci donne le code source. Cela est valable pour les
    logiciels libres mais encore plus pour les objets. Car pour les logiciels libres, on peut s’en servir
    sans comprendre le code source, on le compile et on utilise ensuite le logiciel, tandis que pour
    les objets, on ne peut pas les fabriquer si on ne comprend pas le code source. D’où l’importance
    de diffuser des notices complètes et détaillées pour permettre une réelle appropriation.
    
    * * *
    - Les services connexes comme la formation peuvent être aussi de moyen de rémunération.
    On donne le « code source » des objets, par contre on fait payer la formation qui permet
    d’apprendre à le fabriquer ou les éventuelles recherches pour adapter l’objet à de nouveaux
    usages. C'est le modèle économique qui a été choisi pour financer les logiciels libres.
    
    * * *
    Nous proposons à des particuliers, des entreprises, des associations ou des personnes
    issues de structures d'insertion partenaires de co-construire de A à Z un objet dont ils
    ont besoin. Au cours d'une série d'ateliers, les personnes participent à la conception, à
    la réalisation puis à la documentation de leur objet. A l'aide d'une pédagogie autonomisante,
    les participants sont impliqués pleinement dans le processus de construction, ce qui
    permet de développer des réponses plus proches de leurs besoins, plus durables. C’est
    aussi un moyen d’acquérir des compétences dans différents domaines (écologie, ingénierie,
    travail collectif,...) et de (re-)prendre confiance en soi. Chaque objet est accompagné
    d'une notice de réalisation diffusée sous licence libre, cette notice permettant également
    à d'autres personnes de construire, d’améliorer et de diffuser cet objet.
    
    * * *
    En accord avec les principes de l'auto-production [25], les ateliers sont conçus comme
    un moment d’échange de pratiques et de connaissances. Pour cela, les animateurs ne
    prennent pas de posture d'experts, animent sans imposer, questionnent sans décider et
    travaillent à la prise en compte et à la valorisation des apports des participants. Les
    ateliers se déroulent de la manière suivante : on commence par élaborer un cahier des
    charges regroupant les besoins de l'usager et les contrainte du contexte ; on conçoit
    ensuite le produit, en élaborant des croquis jusqu'à la réalisation de dessins 3D sur
    ordinateur. A partir de ces plans, on fabrique l'objet. Et enfin on réalise une notice de
    documentation qui sera diffusée sous licence libre. Cette formule complète est adaptable
    suivant les possibilités, les usagers pourront ne participer qu'à certaines phases (seulement
    la fabrication par exemple) à l’exception de la phase d'élaboration du cahier des charges
    qui devra être effectuée obligatoirement avec l'usager. Le financement de ces ateliers
    peut provenir de subventions (pour les personnes issues des structures d'insertion), de
    fonds privés de particuliers ou d'entreprises, ou pour les salariés, de Droits Individuels
    à la Formation (DIF).
    
    * * *
    En France, toute utilisation
    d’une invention protégée dans un cadre privé, non commercial ou à des fins expérimentales
    est légale, code de la propriété intellectuelle (article L. 613-5).
    
    * * *
    Un nouveau paradigme est à construire où le designer financerait ses recherches en
    amont et toucherait une rémunération par la transmission de savoir-faire lors de formations
    plus que par la vente d’objets.
    """

-->

<style>
p.authors + h2 {
    font-size: 1em !important;
}
body {
    font-family: Karla;
}
h1, h2, h3, h4, blockquote, footer, .footer {
    font-family: Karla !important;
}
h3 {
    font-family: Karla !important;
}
blockquote {
    font-family: Karla !important;
}

h2 {
    font-weight: bold;
}
</style>


<script>
    var customPageWidth = "210mm";
    var customPageHeight = "297mm";
    var customPageNumber = 5;
    var crop = "0";
</script>
